aboutsummaryrefslogtreecommitdiffstats
path: root/make-version.pl
diff options
context:
space:
mode:
authorMichael Mann <mmann78@netscape.net>2014-01-08 04:35:28 +0000
committerMichael Mann <mmann78@netscape.net>2014-01-08 04:35:28 +0000
commitbf284da2eef917f8bf55be3aad15bb296072bb77 (patch)
treefbf66f67fb32e3d49466867e62a1c07a03300283 /make-version.pl
parenta6ed8a1de97a70668a8feaeade2a11cc4c93185f (diff)
TFShark (Terminal Fileshark) v.001. Bug 9607 (https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=9607)
This is a VERY PRELIMINARY version of tfshark. It's an attempt to jumpstart FileShark and its architecture. Right now it's mostly just a very stripped down version of tshark with all of the necessary build modifications (including now building filetap library since tfshark depends on it) This code has helped me identify what I believe to be all of the necessary layers for a complete fileshark architecture. And those layers will slowly be added in time (patches always welcome!). svn path=/trunk/; revision=54646
Diffstat (limited to 'make-version.pl')
-rwxr-xr-xmake-version.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/make-version.pl b/make-version.pl
index 3593b626ed..b3f6b55a26 100755
--- a/make-version.pl
+++ b/make-version.pl
@@ -442,7 +442,7 @@ sub update_debian_wcf
while ($line = <DWCF>) {
# /usr/lib/wireshark/libwireshark.so.1.1.0
- if ($line =~ qr{^(/usr/lib/wireshark/lib(wireshark|wiretap).so\.\d+\.\d+\.)\d+$}) {
+ if ($line =~ qr{^(/usr/lib/wireshark/lib(wireshark|wiretap|filetap).so\.\d+\.\d+\.)\d+$}) {
$line = sprintf("$1%d\n", $version_pref{"version_micro"});
}
$contents .= $line
@@ -469,10 +469,10 @@ sub update_lib_releases
# "If the library source code has changed at all since the last
# update, then increment revision (‘c:r:a’ becomes ‘c:r+1:a’)."
# epan changes with each minor release, almost by definition. wiretap
# changes with *most* releases.
#
# http://www.gnu.org/software/libtool/manual/libtool.html#Updating-version-info
- for $filedir ("epan", "wiretap") { # "wsutil"
+ for $filedir ("epan", "wiretap", "filetap") { # "wsutil"
$contents = "";
$filepath = $filedir . "/Makefile.am";
open(MAKEFILE_AM, "< $filepath") || die "Can't read $filepath!";
@@ -469,10 +469,10 @@ sub update_lib_releases
# update, then increment revision (‘c:r:a’ becomes ‘c:r+1:a’)."
# epan changes with each minor release, almost by definition. wiretap
- # changes with *most* releases.
+ # and filetap changes with *most* releases.
#
# http://www.gnu.org/software/libtool/manual/libtool.html#Updating-version-info